import { Stats } from 'node:fs';
import { Matcher } from 'picomatch';

type Encoding = "utf8" | "buffer";
type Dir = string | Uint8Array;
type RRDirOpts = {
    strict?: boolean;
    stats?: boolean;
    followSymlinks?: boolean;
    include?: string[];
    exclude?: string[];
    insensitive?: boolean;
};
type InternalOpts = {
    includeMatcher?: Matcher;
    excludeMatcher?: Matcher;
    encoding?: Encoding;
};
type Entry = {
    /** The path to the entry, will be relative if `dir` is given relative. If `dir` is a `Uint8Array`, this will be too. Always present. */
    path: Dir;
    /** Boolean indicating whether the entry is a directory. `undefined` on error. */
    directory?: boolean;
    /** Boolean indicating whether the entry is a symbolic link. `undefined` on error. */
    symlink?: boolean;
    /** A [`fs.stats`](https://nodejs.org/api/fs.html#fs_class_fs_stats) object, present when `options.stats` is set. `undefined` on error. */
    stats?: Stats;
    /** Any error encountered while reading this entry. `undefined` on success. */
    err?: Error;
};
export declare function rrdir(dir: Dir, opts?: RRDirOpts, { includeMatcher, excludeMatcher, encoding }?: InternalOpts): AsyncGenerator<Entry>;
export declare function rrdirAsync(dir: Dir, opts?: RRDirOpts, { includeMatcher, excludeMatcher, encoding }?: InternalOpts): Promise<Entry[]>;
export declare function rrdirSync(dir: Dir, opts?: RRDirOpts, { includeMatcher, excludeMatcher, encoding }?: InternalOpts): Entry[];
export {};
